==> openshift-model-config-6.5.1-sources.jar: io/fabric8/openshift/api/model/config/v1/ClusterOperatorListFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ClusterOperatorListFluent<A extends ClusterOperatorListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,ClusterOperator item);
  public A setToItems(Integer index,ClusterOperator item);
  public A addToItems(io.fabric8.openshift.api.model.config.v1.ClusterOperator... items);
  public A addAllToItems(Collection<ClusterOperator> items);
  public A removeFromItems(io.fabric8.openshift.api.model.config.v1.ClusterOperator... items);
  public A removeAllFromItems(Collection<ClusterOperator> items);
  public A removeMatchingFromItems(Predicate<ClusterOperatorBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ClusterOperator> getItems();
  public List<ClusterOperator> buildItems();
  public ClusterOperator buildItem(Integer index);
  public ClusterOperator buildFirstItem();
  public ClusterOperator buildLastItem();
  public ClusterOperator buildMatchingItem(Predicate<ClusterOperatorBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ClusterOperatorBuilder> predicate);
  public A withItems(List<ClusterOperator> items);
  public A withItems(io.fabric8.openshift.api.model.config.v1.ClusterOperator... items);
  public Boolean hasItems();
  public ClusterOperatorListFluent.ItemsNested<A> addNewItem();
  public ClusterOperatorListFluent.ItemsNested<A> addNewItemLike(ClusterOperator item);
  public ClusterOperatorListFluent.ItemsNested<A> setNewItemLike(Integer index,ClusterOperator item);
  public ClusterOperatorListFluent.ItemsNested<A> editItem(Integer index);
  public ClusterOperatorListFluent.ItemsNested<A> editFirstItem();
  public ClusterOperatorListFluent.ItemsNested<A> editLastItem();
  public ClusterOperatorListFluent.ItemsNested<A> editMatchingItem(Predicate<ClusterOperatorBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,ClusterOperatorFluent<ClusterOperatorListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/ClusterOperatorListFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ClusterOperatorListFluent<A extends ClusterOperatorListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,ClusterOperator item);
  public A setToItems(int index,ClusterOperator item);
  public A addToItems(io.fabric8.openshift.api.model.config.v1.ClusterOperator... items);
  public A addAllToItems(Collection<ClusterOperator> items);
  public A removeFromItems(io.fabric8.openshift.api.model.config.v1.ClusterOperator... items);
  public A removeAllFromItems(Collection<ClusterOperator> items);
  public A removeMatchingFromItems(Predicate<ClusterOperatorBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ClusterOperator> getItems();
  public List<ClusterOperator> buildItems();
  public ClusterOperator buildItem(int index);
  public ClusterOperator buildFirstItem();
  public ClusterOperator buildLastItem();
  public ClusterOperator buildMatchingItem(Predicate<ClusterOperatorBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ClusterOperatorBuilder> predicate);
  public A withItems(List<ClusterOperator> items);
  public A withItems(io.fabric8.openshift.api.model.config.v1.ClusterOperator... items);
  public Boolean hasItems();
  public ClusterOperatorListFluent.ItemsNested<A> addNewItem();
  public ClusterOperatorListFluent.ItemsNested<A> addNewItemLike(ClusterOperator item);
  public ClusterOperatorListFluent.ItemsNested<A> setNewItemLike(int index,ClusterOperator item);
  public ClusterOperatorListFluent.ItemsNested<A> editItem(int index);
  public ClusterOperatorListFluent.ItemsNested<A> editFirstItem();
  public ClusterOperatorListFluent.ItemsNested<A> editLastItem();
  public ClusterOperatorListFluent.ItemsNested<A> editMatchingItem(Predicate<ClusterOperatorBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,ClusterOperatorFluent<ClusterOperatorListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
